@@ -29,6 +29,7 @@ ShellDBusClient::ShellDBusClient(QObject *parent)
 
 void ShellDBusClient::connectSignals()
 {
+    connect(m_interface, &OrgKdePlasmashellInterface::panelStateChanged, this, &ShellDBusClient::updatePanelState);
     connect(m_interface, &OrgKdePlasmashellInterface::isActionDrawerOpenChanged, this, &ShellDBusClient::updateIsActionDrawerOpen);
     connect(m_interface, &OrgKdePlasmashellInterface::doNotDisturbChanged, this, &ShellDBusClient::updateDoNotDisturb);
     connect(m_interface, &OrgKdePlasmashellInterface::isTaskSwitcherVisibleChanged, this, &ShellDBusClient::updateIsTaskSwitcherVisible);
@@ -47,6 +48,16 @@ void ShellDBusClient::connectSignals()
     updateIsTaskSwitcherVisible();
 }
 
+QString ShellDBusClient::panelState() const
+{
+    return m_panelState;
+}
+
+void ShellDBusClient::setPanelState(QString state)
+{
+    m_interface->setPanelState(state);
+}
+
 bool ShellDBusClient::doNotDisturb() const
 {
     return m_doNotDisturb;
@@ -113,6 +124,18 @@ void ShellDBusClient::showVolumeOSD()
     m_interface->showVolumeOSD();
 }
 
+void ShellDBusClient::updatePanelState()
+{
+    auto reply = m_interface->panelState();
+    auto watcher = new QDBusPendingCallWatcher(reply, this);
+
+    QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](auto watcher) {
+        QDBusPendingReply<QString> reply = *watcher;
+        m_panelState = reply.argumentAt<0>();
+        Q_EMIT panelStateChanged();
+    });
+}
+
 void ShellDBusClient::updateDoNotDisturb()
 {
     auto reply = m_interface->doNotDisturb();
