@@ -24,13 +24,14 @@ MobileShellSettings::MobileShellSettings(QObject *parent)
     , m_config{KSharedConfig::openConfig(CONFIG_FILE, KConfig::SimpleConfig)}
 {
     m_configWatcher = KConfigWatcher::create(m_config);
-
     connect(m_configWatcher.data(), &KConfigWatcher::configChanged, this, [this](const KConfigGroup &group, const QByteArrayList &names) -> void {
+        Q_UNUSED(names)
         if (group.name() == GENERAL_CONFIG_GROUP) {
             Q_EMIT vibrationsEnabledChanged();
             Q_EMIT vibrationDurationChanged();
             Q_EMIT animationsEnabledChanged();
             Q_EMIT dateInStatusBarChanged();
+            Q_EMIT statusBarScaleFactorChanged();
             Q_EMIT navigationPanelEnabledChanged();
             Q_EMIT alwaysShowKeyboardToggleOnNavigationPanelChanged();
             Q_EMIT keyboardButtonEnabledChanged();
@@ -38,6 +39,7 @@ MobileShellSettings::MobileShellSettings(QObject *parent)
             Q_EMIT actionDrawerTopLeftModeChanged();
             Q_EMIT actionDrawerTopRightModeChanged();
             Q_EMIT convergenceModeEnabledChanged();
+            Q_EMIT allowLogoutChanged();
         }
     });
 }
@@ -94,6 +96,19 @@ void MobileShellSettings::setDateInStatusBar(bool dateInStatusBar)
     m_config->sync();
 }
 
+float MobileShellSettings::statusBarScaleFactor() const
+{
+    auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
+    return group.readEntry("statusBarScaleFactor", 1.0);
+}
+
+void MobileShellSettings::setStatusBarScaleFactor(float statusBarScaleFactor)
+{
+    auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
+    group.writeEntry("statusBarScaleFactor", statusBarScaleFactor, KConfigGroup::Notify);
+    m_config->sync();
+}
+
 bool MobileShellSettings::navigationPanelEnabled() const
 {
     auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
@@ -203,3 +218,9 @@ void MobileShellSettings::updateNavigationBarsInPlasma(bool navigationPanelEnabl
     // TODO check for error response
     QDBusConnection::sessionBus().asyncCall(message);
 }
+
+bool MobileShellSettings::allowLogout() const
+{
+    auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
+    return group.readEntry("allowLogout", true);
+}
